import '../index.less';
import React, { useContext } from 'react';
import classNames from 'classnames';
import warning from "rc-util/es/warning";
import isEqual from 'lodash.isequal';
import DiffContext from '../Context';
import { RenderLabel, RenderContent } from '../Content';
import { getArrayLast, getValue } from '../valueUtil';

var getArrayValue = function getArrayValue(value, name) {
  var result = getValue(value, name);

  if (Array.isArray(result)) {
    return result;
  }

  if (typeof result === 'string') {
    return [result];
  }

  return [];
};

var Radio = function Radio(props) {
  var _useContext = useContext(DiffContext),
      before = _useContext.before,
      after = _useContext.after,
      constants = _useContext.constants;

  var label = props.label,
      name = props.name,
      propsClassName = props.className;
  var hasArray = name.some(function (item) {
    return Array.isArray(item);
  });

  if (hasArray) {
    // 映射类型暂时不支持多维数组
    warning(false, '`Radio` type do not support Array');
    return null;
  }

  var IteratorValue = function IteratorValue(values) {
    if (values.length === 0) {
      return '-';
    }

    return values.map(function (value) {
      return React.createElement("span", {
        className: classNames('space'),
        key: "".concat(value)
      }, value && constants[getArrayLast(name)] ? constants[getArrayLast(name)][value] : '');
    });
  };

  var beforeValue = getArrayValue(before, name);
  var afterValue = getArrayValue(after, name);
  var isSame = isEqual(beforeValue, afterValue);
  return React.createElement("div", {
    className: classNames('space-divide', propsClassName)
  }, React.createElement(RenderLabel, {
    isSame: isSame,
    label: label
  }), React.createElement(RenderContent, {
    isSame: isSame,
    beforeNode: IteratorValue(beforeValue),
    afterNode: IteratorValue(afterValue)
  }));
};

export default Radio;